@@ -3,4 +3,4 @@ if (inherits(ga, "try-error"))
     ga <- RGA::ga
 
 cn <- colnames(ga)
-selected <- c("id", "ui.name", "type", "description")
+selected <- c("id", "uiName", "type", "description")
